@@ -10,7 +10,7 @@ from django.utils.functional import cached_property
 from django.views.generic import DetailView, RedirectView
 from django.views.generic.detail import SingleObjectMixin
 
-from simpl import conf, get_run_model, nav
+from simpl import conf, get_run_model, get_player_model, nav
 
 from . import models
 
@@ -91,7 +91,15 @@ class InitialView(SingleObjectMixin, RedirectView):
 class StatusView(SimplMixin, DetailView):
     simpl_name = "status"
 
+    @cached_property
+    def ready(self):
+        return (
+            self.run.multiplayer is False
+            or not self.run.player_set.unbalanced().exists()
+        )
+
     def get_context_data(self, **kwargs):
+        kwargs["ready"] = self.ready
         kwargs["configured"] = True
         kwargs["next_item"] = nav.get_next_item(self.run, self.simpl_name)
         return super().get_context_data(**kwargs)
@@ -133,6 +141,16 @@ class PlayersView(SimplMixin, DetailView):
             context["next_url"] = nav.get_next_url(self.run, self.simpl_name)
         return context
 
+    def post(self, request, **kwargs):
+        Player = get_player_model()
+        deactivate = request.POST.getlist("deactivate")
+        if deactivate:
+            Player.objects.filter(pk__in=deactivate).update(inactive=True)
+        reactivate = request.POST.getlist("reactivate")
+        if reactivate:
+            Player.objects.filter(pk__in=reactivate).update(inactive=False)
+        return redirect(".")
+
 
 class StartView(SimplMixin, DetailView):
     simpl_name = "start"
